@@ -8,7 +8,7 @@
 #ifndef EVENTLOGGERREGISTER_H
 #define EVENTLOGGERREGISTER_H
 
-#include <QVector>
+#include <QList>
 
 #include <memory>
 
@@ -21,7 +21,7 @@ class PROXYMODELTESTSUITE_EXPORT EventLoggerRegister
 public:
     enum Behaviour {
         InstallMsgHandler,
-        NoInstallMsgHandler
+        NoInstallMsgHandler,
     };
 
     ~EventLoggerRegister();
@@ -35,7 +35,7 @@ public:
 
 private:
     EventLoggerRegister(Behaviour behaviour);
-    QVector<ModelEventLogger *> m_loggers;
+    QList<ModelEventLogger *> m_loggers;
 
     static EventLoggerRegister *s_instance;
 
